@@ -12,16 +12,16 @@ from allauth.socialaccount.providers.openid.provider import (
 class SteamAccount(OpenIDAccount):
     def to_str(self):
         dflt = super(SteamAccount, self).to_str()
-        return self.account.extra_data.get('personaname', dflt)
+        return self.account.extra_data.get("personaname", dflt)
 
     def get_profile_url(self):
         return self.account.extra_data.get("profileurl")
 
     def get_avatar_url(self):
         return (
-            self.account.extra_data.get("avatarfull") or
-            self.account.extra_data.get("avatarmedium") or
-            self.account.extra_data.get("avatar")
+            self.account.extra_data.get("avatarfull")
+            or self.account.extra_data.get("avatarmedium")
+            or self.account.extra_data.get("avatar")
         )
 
 
@@ -35,6 +35,7 @@ def request_steam_account_summary(api_key, steam_id):
     params = {"key": api_key, "steamids": steam_id}
 
     resp = requests.get(api_base + method, params)
+    resp.raise_for_status()
     data = resp.json()
 
     playerlist = data.get("response", {}).get("players", [])
@@ -55,9 +56,7 @@ class SteamOpenIDProvider(OpenIDProvider):
     def sociallogin_from_response(self, request, response):
         steam_id = extract_steam_id(response.identity_url)
         steam_api_key = self.get_app(request).secret
-        response._extra = request_steam_account_summary(
-            steam_api_key, steam_id
-        )
+        response._extra = request_steam_account_summary(steam_api_key, steam_id)
         return super(SteamOpenIDProvider, self).sociallogin_from_response(
             request, response
         )
